Brawlers

Enum Brawlers 

#[non_exhaustive]
pub enum Brawlers {
Show 33 variants Shelly = 16_000_000, Colt = 16_000_001, Bull = 16_000_002, Brock = 16_000_003, Rico = 16_000_004, Spike = 16_000_005, Barley = 16_000_006, Jessie = 16_000_007, Nita = 16_000_008, Dynamike = 16_000_009, ElPrimo = 16_000_010, Mortis = 16_000_011, Crow = 16_000_012, Poco = 16_000_013, Bo = 16_000_014, Piper = 16_000_015, Pam = 16_000_016, Tara = 16_000_017, Darryl = 16_000_018, Penny = 16_000_019, Frank = 16_000_020, Gene = 16_000_021, Tick = 16_000_022, Leon = 16_000_023, Rosa = 16_000_024, Carl = 16_000_025, Bibi = 16_000_026, EightBit = 16_000_027, Sandy = 16_000_028, Bea = 16_000_029, Emz = 16_000_030, MrP = 16_000_031, Max = 16_000_032,
}
This eunm is an effort to aid the programmer’s usage of brawler-related endpoints, by mapping human-readable brawler names to their respective IDs. (Use by casting to int; e.g. x as usize)

This is by no means a final enum and must be updated on every new Brawler release.

If a permanently up-to-date list is needed, one can fetch the /brawlers/ endpoint using the available models. If still using this enum, though, rest assured that we will do our best to keep it updated - if it is not, why not contribute with a PR? ;)

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Shelly = 16_000_000



Colt = 16_000_001



Bull = 16_000_002



Brock = 16_000_003



Rico = 16_000_004



Spike = 16_000_005



Barley = 16_000_006



Jessie = 16_000_007



Nita = 16_000_008



Dynamike = 16_000_009



ElPrimo = 16_000_010



Mortis = 16_000_011



Crow = 16_000_012



Poco = 16_000_013



Bo = 16_000_014



Piper = 16_000_015



Pam = 16_000_016



Tara = 16_000_017



Darryl = 16_000_018



Penny = 16_000_019



Frank = 16_000_020



Gene = 16_000_021



Tick = 16_000_022



Leon = 16_000_023



Rosa = 16_000_024



Carl = 16_000_025



Bibi = 16_000_026



EightBit = 16_000_027



Sandy = 16_000_028



Bea = 16_000_029



Emz = 16_000_030



MrP = 16_000_031



Max = 16_000_032