Module error

Module error 

Contains the Error enum, used in all functions of the library that may error (fetches).

Structs

APIError
Represents an error given by the API, with its specifications.

Enums

Error
Represents all possible errors while using methods from this lib (brawl-api) in functions such as fetches.

Type Aliases

Result
Represents a brawl-api Result type.