Player

Struct Player 

pub struct Player {
Show 17 fields pub club: Option<PlayerClub>, pub is_qualified_from_championship_challenge: bool, pub tvt_victories: usize, pub tag: String, pub name: String, pub trophies: usize, pub highest_trophies: usize, pub exp_level: usize, pub exp_points: usize, pub power_play_points: usize, pub highest_power_play_points: usize, pub solo_victories: usize, pub duo_victories: usize, pub best_robo_rumble_time: usize, pub best_time_as_big_brawler: usize, pub brawlers: Vec<PlayerBrawlerStat>, pub name_color: u64,
}
A struct representing a Brawl Stars player, with all of its data. Use Player::fetch to fetch one based on tag. (Make sure the PropFetchable trait is imported - in general, it is recommended to at least use brawl_api::traits::*, or, even, use brawl_api::prelude::* to bring the models into scope as well.)

Fields

club: Option<PlayerClub>

The club the Player is in (as a PlayerClub instance), or None if none.

is_qualified_from_championship_challenge: bool

Whether or not the Player was qualified from the Championship challenge (2020).

tvt_victories: usize

Amount of 3v3 victories the Player has earned.

tag: String

The player’s tag. Note: this includes the initial ‘#’.

name: String

The player’s name.

trophies: usize

The player’s current trophies.

highest_trophies: usize

The player’s highest trophies amount.

exp_level: usize

The player’s experience level.

exp_points: usize

The player’s experience points.

power_play_points: usize

The player’s current power play points.

highest_power_play_points: usize

The player’s highest power play points.

solo_victories: usize

The player’s victories in solo showdown (how many times ranked #1).

duo_victories: usize

The player’s victories in duo showdown (how many times ranked #1).

best_robo_rumble_time: usize

The player’s best Robo Rumble time, in seconds.

best_time_as_big_brawler: usize

The player’s best time as a Big Brawler, in seconds.

brawlers: Vec<PlayerBrawlerStat>

The player’s brawlers.

name_color: u64

The player’s name color, as an integer (Default is 0xffffff = 16777215 - this is used when the data is not available).