pub trait GetFetchProp: Sized {
type Property: ?Sized;
// Required methods
fn get_fetch_prop(&self) -> &Self::Property;
fn get_route(prop: &Self::Property) -> Route;
}Expand description
A trait representing a type with a property used to be fetched, and a route with which to fetch it. This can be either a tag or the limit of fetching, for example.
The property must be returned by the get_fetch_prop function.
The route must be returned by the get_route function.
This trait is used in parallel with PropFetchable.
Required Associated Types
Required Methods
Sourcefn get_fetch_prop(&self) -> &Self::Property
fn get_fetch_prop(&self) -> &Self::Property
Obtain the revelant property for fetching.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".