Traits
- Prop
LimFetchable - A trait representing a type whose instance can be fetched from the API using some property and specifying a limit of how many objects to fetch.
- Prop
LimRouteable - A trait representing a type that returns a
Routeobject given a property and a limit of how many to fetch.