Module time

Module time 

Contains the TimeLike struct, used to indicate strings that contain timestamps which can be parsed using TimeLike.parse (if the chrono feature is enabled, otherwise the method is not implemented).

Modules

_impls

Structs

TimeLike
Represents a timestamp provided by the Brawl API. If the chrono feature is enabled (it is by default), then it is possible to use helper methods to convert it to chrono data structures - see TimeLike.parse (this is recommended, as it is aware of the correct format).