Module proplimfetch

Module proplimfetch 

Traits

PropLimFetchable
A trait representing a type whose instance can be fetched from the API using some property and specifying a limit of how many objects to fetch.
PropLimRouteable
A trait representing a type that returns a Route object given a property and a limit of how many to fetch.