PropLimRouteable

Trait PropLimRouteable 

pub trait PropLimRouteable {
    type Property: ?Sized;
    type Limit: PrimInt;

    // Required method
    fn get_route(prop: &Self::Property, limit: Self::Limit) -> Route;
}
A trait representing a type that returns a Route object given a property and a limit of how many to fetch.

Required Associated Types

Required Methods

fn get_route(prop: &Self::Property, limit: Self::Limit) -> Route

Obtain the route for fetching by using a property and specifying the limit of fetching.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors