pub trait FetchInto<T>: Sized {
// Required methods
fn fetch_into(&self, client: &Client) -> Result<T>;
fn a_fetch_into<'life0, 'life1, 'async_trait>(
&'life0 self,
client: &'life1 Client,
) -> Pin<Box<dyn Future<Output = Result<T>> + Send + 'async_trait>>
where T: 'async_trait,
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
}Expand description
A trait indicating that this type can be converted into another by fetching from the API.
Note that FetchFrom should be implemented, in order to apply the respective blanket
implementation of this trait.
Required Methods
Sourcefn fetch_into(&self, client: &Client) -> Result<T>
fn fetch_into(&self, client: &Client) -> Result<T>
Sourcefn a_fetch_into<'life0, 'life1, 'async_trait>(
&'life0 self,
client: &'life1 Client,
) -> Pin<Box<dyn Future<Output = Result<T>> + Send + 'async_trait>>where
T: 'async_trait,
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn a_fetch_into<'life0, 'life1, 'async_trait>(
&'life0 self,
client: &'life1 Client,
) -> Pin<Box<dyn Future<Output = Result<T>> + Send + 'async_trait>>where
T: 'async_trait,
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.